"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var messenger_1 = require("./messenger");
var rxjs_1 = require("./vendor/rxjs");
// -------------------------------------------------------------------------------------
// Private data / exports for internal wiring
// -------------------------------------------------------------------------------------
/**
 * The observable implementation to use for creating the event streams of new messengers.
 */
var _Observable = rxjs_1.Observable;
/**
 * returns the active Rx.Observable implementation. Used by the messenger class to
 * obtain an Observable constructor reference at runtime.
 *
 * @return {Class<Observable>}
 */
function getObservable() {
    return _Observable;
}
exports.getObservable = getObservable;
// -------------------------------------------------------------------------------------
// API implementation
// -------------------------------------------------------------------------------------
/**
 * Sets given Rx.Observable implementation as the active implementation for new messengers.
 * Any messenger created hereafter will use this implementation.
 *
 * @param {Class<Observable>} newImplementation
 */
function useObservable(newImplementation) {
    _Observable = newImplementation;
}
exports.useObservable = useObservable;
/**
 * @param {Window} otherWindow
 * @param {string} origin
 * @return {IMessenger}
 */
function connect(otherWindow, origin) {
    return new messenger_1.Messenger(otherWindow, origin);
}
exports.connect = connect;
// ---------------------------------------------------------------------------------------
// API Exports
// ---------------------------------------------------------------------------------------
var defaultNamespace = { connect: connect, useObservable: useObservable, getObservable: getObservable };
exports.default = defaultNamespace;
//# sourceMappingURL=index.js.map