import { Messenger } from "./messenger";
import { Observable } from "./vendor/rxjs";
// -------------------------------------------------------------------------------------
// Private data / exports for internal wiring
// -------------------------------------------------------------------------------------
/**
 * The observable implementation to use for creating the event streams of new messengers.
 */
var _Observable = Observable;
/**
 * returns the active Rx.Observable implementation. Used by the messenger class to
 * obtain an Observable constructor reference at runtime.
 *
 * @return {Class<Observable>}
 */
export function getObservable() {
    return _Observable;
}
// -------------------------------------------------------------------------------------
// API implementation
// -------------------------------------------------------------------------------------
/**
 * Sets given Rx.Observable implementation as the active implementation for new messengers.
 * Any messenger created hereafter will use this implementation.
 *
 * @param {Class<Observable>} newImplementation
 */
export function useObservable(newImplementation) {
    _Observable = newImplementation;
}
/**
 * @param {Window} otherWindow
 * @param {string} origin
 * @return {IMessenger}
 */
export function connect(otherWindow, origin) {
    return new Messenger(otherWindow, origin);
}
// ---------------------------------------------------------------------------------------
// API Exports
// ---------------------------------------------------------------------------------------
var defaultNamespace = { connect: connect, useObservable: useObservable, getObservable: getObservable };
export default defaultNamespace;
//# sourceMappingURL=index.js.map